@@ -13,10 +13,6 @@ class AutoTeam:
         else:
             model = os.getenv("AI_AGENT", "openai")
             self.proxy = None
-            # if model == "autogen":
-            #     self.proxy = AutoGenAgent()
-            # if model == "local":
-            #     self.proxy = LocalAIAgent()
             if model == "openai":
                 self.proxy = OpenAIAgent()
             elif model == "mockai":
@@ -24,6 +20,9 @@ class AutoTeam:
             else:
                 raise Exception("Invalid model")
 
+    def generate_audio(self, prompt, **kwargs):
+        return self.proxy.generate_audio(prompt, **kwargs)
+
     def generate_image(self, prompt, **kwargs):
         return self.proxy.generate_image(prompt, **kwargs)
 
@@ -31,12 +30,26 @@ class AutoTeam:
         self,
         text,
         functions,
+        name="json_agent",
         primer_text="",
+        file_data=None,
+        context=[],
     ):
-        return self.proxy.generate_json(text, functions, primer_text)
+        return self.proxy.generate_json(
+            text,
+            functions,
+            name=name,
+            primer_text=primer_text,
+            file_data=file_data,
+            context=context,
+        )
 
-    def generate_text(self, text, primer_text=""):
-        return self.proxy.generate_text(text, primer_text)
+    def generate_text(
+        self, text, name="json_agent", primer_text="", file=None, context=[]
+    ):
+        return self.proxy.generate_text(
+            text, name=name, primer_text=primer_text, file_data=file, context=context
+        )
 
     def summarize_text(self, text, primer=""):
         return self.proxy.summarize_text(text, primer)
