@@ -15,7 +15,7 @@ class AutoUser(AutoModel):
 
     attributes = {
         "name": AutoAttribute("TEXT", required=True),
-        "email": AutoAttribute("TAG", required=True),
+        "email": AutoAttribute("TEXT", required=True),
         "last_login": datetime.now(),
         "state": "unauthenticated",
         "provider": None,
@@ -23,6 +23,9 @@ class AutoUser(AutoModel):
         "token": None,
     }
 
+    def __eq__(self, other):
+        return self.pk == other.pk
+
     @classmethod
     def authenticate(cls, user_info, token=None):
         """
@@ -31,16 +34,9 @@ class AutoUser(AutoModel):
         """
         email = user_info["email"].strip()
         name = user_info["name"].strip()
-        # log(cls, user_info)
         user = cls.find(email=email)
-        # log(user)
         if not user:
-            # FIXME: attempting a lookup hack because something is fucked up
-            for u in cls.all():
-                if u.email == email:
-                    user = u
-        if not user:
-            # log("Creating new user...")
+            log(f"Creating new user for {email}")
             user = cls(name=name, email=email)
 
         # parse user_info into a user object
@@ -49,7 +45,6 @@ class AutoUser(AutoModel):
         user.last_login = datetime.now()
         user.state = "authenticated"
         user.save()
-        # log(user.pk)
         return user
 
     @property
