@@ -45,7 +45,7 @@ class CloudinaryStorage:
         if folder := kwargs.get("folder"):
             try:
                 cloudinary.api.subfolders(f"{folder}")
-            except cloudinary.exceptions.NotFound as e:
+            except cloudinary.exceptions.NotFound:
                 # log(f"{e} -- Creating folder {folder}")
                 cloudinary.api.create_folder(folder)
             finally:
@@ -56,9 +56,18 @@ class CloudinaryStorage:
         except Exception as e:
             log("Cloudinary Storage upload error")
             raise e
-        #log(response)
+        # log(response)
         return {"asset_id": response["asset_id"], "url": response["url"]}
 
+    def move(self, key, folder):
+        metadata = self.get_metadata(key)
+        new_id = f"{folder}/{metadata['public_id'].split('/')[-1]}"
+        asset = cloudinary.uploader.rename(
+            metadata["public_id"],
+            new_id,
+        )
+        return {"asset_id": asset["asset_id"], "url": asset["url"]}
+
     def remove(self, asset_id, **kwargs):
         response = self.get_metadata(asset_id)
-        cloudinary.uploader.destroy(response["public_id"], **kwargs)
+        return cloudinary.uploader.destroy(response["public_id"], **kwargs)
